@@ -12,7 +12,8 @@ uniq < c.tmp > b.tmp
 
 perl build_OOo_dictionary_step_3.pl < b.tmp >> a.tmp
 
-sort < a.tmp > b.tmp
+# Sort in C locale as author of aspell recomends it
+LC_ALL=C sort < a.tmp > b.tmp
 uniq < b.tmp > a.tmp
 
 perl build_OOo_dictionary_step_4.pl < a.tmp > b.tmp
