@@ -9,5 +9,4 @@ echo "Converting data ..."
 
 ./OOo2ispell.awk < bg_BG.aff > bulgarian.aff
 
-tail +2 < bg_BG.dic | sort -t/ -k1,1 -f > bulgarian.dict
-
+tail -n +2 < bg_BG.dic | LC_ALL=C sort -t/ -k1,1 -f > bulgarian.dict
