@@ -40,8 +40,9 @@ while ($file_name = next_file($file_name)) {
 	my @e = get_endings($file_name);
 	my $f = $e[0];
 	my @w = get_words($file_name);
+	my $words = $#w + 1;
 
-	print "$type, $num, $#w, ";
+	print "$type, $num, $words, ";
 
 	my $aff = -1;
 	for (@e) {
@@ -51,7 +52,7 @@ while ($file_name = next_file($file_name)) {
 	}
 	print "$aff, ";
 
-	my $total = $aff * $#w;
+	my $total = $aff * $words;
 	print "$total, ";
 
 	if ($f =~ /(.*)\[(.+)\](.*)/) {
