@@ -18,12 +18,14 @@ EOHelp
 }
 
 
+my $verbose = ($ARGV[0] eq "--verbose");
+
 
 my $file_name = "";
 
 while ($file_name = next_file($file_name)) {
 
-	print "Checking $file_name ...\n";
+	print "Checking $file_name ...\n" if $verbose;
 
 	my @e = get_endings($file_name);
 	my @f = get_forms($file_name);
