@@ -20,12 +20,14 @@ EOHelp
 }
 
 
+my $verbose = ($ARGV[0] eq "--verbose");
+
 
 my $file_name = "";
 
 while ($file_name = next_file($file_name)) {
 
-	print "Checking $file_name ...\n";
+	print "Checking $file_name ...\n" if $verbose;
 
 	my @t = get_tests($file_name);
 
