@@ -22,13 +22,14 @@ EOHelp
 	exit;
 }
 
+my $verbose = ($ARGV[0] eq "--verbose");
 
 
 my $file_name = "";
 
 while ($file_name = next_file($file_name)) {
 
-	print "Checking $file_name ...\n";
+	print "Checking $file_name ...\n" if $verbose;
 
 	my $f = get_filter($file_name);
 	my @e = get_endings($file_name);
