@@ -16,6 +16,7 @@ if ($ARGV[0] eq "--help") {
 ,   ,       
    .
 
+
 EOHelp
 
 	exit;
@@ -24,22 +25,15 @@ EOHelp
 
 
 my $file_name = "";
-my $num = "";
-my $c = 0;
+my $type = 0;
 
 while ($file_name = next_file($file_name)) {
 
-	if ($file_name =~ /bg\d\d\d\.dat$/) {
-		$num = substr($file_name, -7, 3);
-	} else {
-		$num = substr($file_name, -8, 4);
-	}
-
-	$c++;
+	$type++;
 
 	my @w = get_words($file_name);
 	for (@w) {
-		print "$_ $c\n";
+		print "$_ $type\n";
 	}
 
 }
