@@ -13,6 +13,7 @@ if ($ARGV[0] eq "--help") {
 
          .
 
+
 EOHelp
 
 	exit;
@@ -31,8 +32,8 @@ my $buffer = "";
 for(@data) {
 	my $p = index($_, " ");
 	if ($p > 0) {
-		$w = substr($_, 0, $p);
-		$t = substr($_, $p + 1);
+		$w = strip_line(substr($_, 0, $p));
+		$t = strip_line(substr($_, $p + 1));
 	} else {
 		die "no space in line <$_>\n";
 	}
